# zandbak

A sandbox python repository for testing GitHub features, CI pipelines, and python
packages.

Some structural mechanics examples are used as dummy code:
 * response of linear elastic beams.
